# Audio Case Grade

![PyPi][pypi-badge]

A Python library (`audio-case-grade`) containing a score algorithm to score audio medical case studies.

## Features

- Score medical audio cases
- Clean transcriptions for medical audio cases

## Install

```bash
pip install audio_case_grade
```

<!-- Relative Links -->

[pypi-badge]: https://img.shields.io/pypi/v/audio-case-grade
